# 簡易暗号化ツール [ezenc]
# 【動作確認 / 使用例】

import sys
import ezpip
ezenc = ezpip.load_develop("ezenc", "../", develop_flag = True)

# 暗号化
enc_res = ezenc.enc(b"hello!", b"test-key")
print(enc_res)

# 復号
dec_res = ezenc.dec(enc_res, b"test-key")
print(dec_res)



# 簡易暗号化ツール [ezenc]

import sys
from Crypto.Cipher import AES
from Crypto.Util.Padding import pad, unpad
from Crypto.Random import get_random_bytes
from Crypto.Hash import SHA256

# keyを256ビット (32バイト) に変換
def fix_key(k): return SHA256.new(k).digest()

# 暗号化
def enc(d, k):
	k = fix_key(k)
	iv = get_random_bytes(16)	# ランダムなinitial-vecにより、安全に毎回異なる暗号文を生成する
	return iv + AES.new(k, AES.MODE_CBC, iv).encrypt(pad(d, 16))

# 復号
def dec(d, k):
	k = fix_key(k)
	return unpad(AES.new(k, AES.MODE_CBC, d[:16]).decrypt(d[16:]), 16)




from setuptools import setup
# 公開用パッケージの作成 [ezpip]
import ezpip

# 公開用パッケージの作成 [ezpip]
with ezpip.packager(develop_dir = "./_develop_ezenc/") as p:
	setup(
		name = "ezenc",
		version = "0.1.1",
		description = "A tool that can easily encrypt and decrypt. Utilizes the symmetric key cryptography method (AES).",
		author = "bib_inf",
		author_email = "contact.bibinf@gmail.com",
		url = "https://github.co.jp/",
		packages = p.packages,
		install_requires = ["ezpip", "pycryptodome>=3.21.0"],
		long_description = p.long_description,
		long_description_content_type = "text/markdown",
		license = "CC0 v1.0",
		classifiers = [
			"Programming Language :: Python :: 3",
			"Topic :: Software Development :: Libraries",
			"License :: CC0 1.0 Universal (CC0 1.0) Public Domain Dedication"
		],
		# entry_points = """
		# 	[console_scripts]
		# 	py6 = py6:console_command
		# """
	)
